/*
 * File......: CPMI.H
 * Author....: Ted Means
 * CIS ID....: 73067,3332
 *
 * This is an original work by Ted Means and is placed in the
 * public domain.
 *
 * Modification history:
 * ---------------------
 *    Rev 1.0   01 Jan 1995 03:01:00   TED
 *    Initial release
 *
 */

//  This is the header file for the Clipper Protected Mode Interface.
//  Modified 2012 by multisoft for FlagShip

#define SUCCEED             1
#define FAIL                0

#define TRUE                1
#define FALSE               0

#define AR_READ             1          // For cpmiWillGPF() & cpmiMakeAlias()
#define AR_WRITE            2          // For cpmiWillGPF() & cpmiMakeAlias()
#define AR_EXECUTE          4          // For cpmiWillGPF() & cpmiMakeAlias()

#define INVALID_SELECTOR   -1          // Returned by cpmiWillGPF()
#define INVALID_ACCESS     -2          // Returned by cpmiWillGPF()
#define BEYOND_LIMIT       -3          // Returned by cpmiWillGPF()

typedef unsigned int  SELECTOR;
typedef unsigned int  REGISTER;
typedef unsigned int  SEGMENT;
typedef unsigned long LINEAR;
typedef unsigned int  BOOLEAN;

typedef union
{
   REGISTER Regs[ 10 ];
   struct
   {
      REGISTER AX;
      REGISTER BX;
      REGISTER CX;
      REGISTER DX;
      REGISTER SI;
      REGISTER DI;
      REGISTER BP;
      REGISTER DS;
      REGISTER ES;
      REGISTER Flags;
   } Reg;
} CPUREGS;

BOOLEAN      cpmiIsProtected( void );
int          cpmiWillGPF( void *, unsigned int, unsigned int );
SELECTOR     cpmiAllocateSelector( void );
unsigned int cpmiFreeSelector( SELECTOR );
SELECTOR     cpmiSegmentToSelector( SEGMENT );
LINEAR       cpmiGetBase( SELECTOR );
unsigned int cpmiSetBase( SELECTOR, LINEAR );
unsigned int cpmiGetLimit( SELECTOR );
unsigned int cpmiSetLimit( SELECTOR, int );
void *       cpmiRealPtr( void * );
SELECTOR     cpmiProtectedPtr( void *, unsigned int );
SELECTOR     cpmiMakeAlias( SELECTOR, unsigned int );
SELECTOR     cpmiAllocateDOSMem( unsigned int );
int          cpmiResizeDOSMem( SELECTOR, unsigned int );
int          cpmiFreeDOSMem( SELECTOR );
int          cpmiInt86( unsigned char, CPUREGS *, CPUREGS * );
int          cpmiFarCallReal( void *, CPUREGS *, CPUREGS * );
SELECTOR     cpmiSeg2Sel( SEGMENT );
