/*
 * File......: SaveSets.Prg
 * Author....: David Husnian
 * CIS ID....: ?
 *
 * This is an original work by David Husnian and is placed in the
 * public domain.
 *
 * Modification history:
 * ---------------------
 *
 *    Rev 1.2   15 Aug 1991 23:05:06   GLENN
 * Forest Belt proofread/edited/cleaned up doc
 *
 *    Rev 1.1   12 Apr 1991 00:18:04   GLENN
 * There was a call to SETCENTURY() that should have been FT_SETCENTURY().
 * Another one of those errors that came from testing earlier versions of
 * a routine before FT_ prefix was added to function names.  Lesson learned.
 *
 *    Rev 1.0   01 Apr 1991 01:02:10   GLENN
 * Nanforum Toolkit
 *
 *
 */


/*  $DOC$
 *  $FUNCNAME$
 *     FT_SAVESETS()
 *  $CATEGORY$
 *     Environment
 *  $ONELINER$
 *     Save the status of all the SET command settings
 *  $SYNTAX$
 *     FT_SAVESETS() -> aOldSets
 *  $ARGUMENTS$
 *     None
 *  $RETURNS$
 *     An array containing the values of the supported SETs.
 *  $DESCRIPTION$
 *     This function saves the SET Settings, i.e., it copies them into an
 *     array, aOldSets.  The following SETs are not currently supported:
 *     FILTER, FORMAT, FUNCTION, INDEX, KEYS, MODE, ORDER, PROCEDURE,
 *     RELATION, TYPEAHEAD
 *  $EXAMPLES$
 *     aOldSets := FT_SAVESETS()
 *  $INCLUDE$
 *     SET.CH
 *  $SEEALSO$
 *     FT_RESTSETS() FT_SETCENTURY()
 *  $END$
 */


**********************************************************************************
#ifdef FT_TEST
function main()
   LOCAL aSets
   SET FONT "courier",10      // FlagShip GUI
   ? "Test for FT_SAVESETS() and FT_RESTSETS()"
   ? "  See also default FlagShip SetKeySave() and SetKeyRest()"
   ? "Supported are also save/restore SET KEY and SET FUNCTION"
   ? "  when FS2 Toolbox is available "
#ifndef VFS_FS2TOOLS 
   ?? "(but FS2Tools lib not found)"
#endif 
   
   ?
   set key K_F1 to dummy1
   set key K_F2 to dummy2
   set function 3 to "hello!"
   
#ifdef VFS_FS2TOOLS  
   ? "Current SET KEY redirections:"   
   _displarrstd(SaveSetKey()) // display keys and UDF name
#endif   
   ? "Current SET DEVICE is " + set(_SET_DEVICE)
   wait "try to press F1 or F2 ..."
   
   aSets := FT_SAVESETS()
   ?
   ? "SETs and redirection for F1 and F2 saved"
   ? "Clearing redirection for F1 and F2"
   set device to print
   ? "setting SET DEVICE TO " + set(_SET_DEVICE)

   set key K_F1 to 
   set key K_F2 to 
   wait "try to press F1 or F2..."
   
   ?
   ? "Restoring SETs and redirection for F1,  F2"
   FT_RESTSETS(aSets)
   ? "Restored SET DEVICE is " + set(_SET_DEVICE)
   wait "try to press F1 or F2..."
   ?
   wait "done..."
   RETURN Nil
   
function dummy1
   alert("in dummy1")
   return
function dummy2
   alert("in dummy2")
   return
#endif
**********************************************************************************

#ifndef FlagShip
#include "set.ch"
#endif

#Define FT_EXTRA_SETS    2
#DEFINE FT_SET_CENTURY   _SET_COUNT + 1
#DEFINE FT_SET_BLINK     _SET_COUNT + 2

FUNCTION  FT_SAVESETS()

   LOCAL aOldSets := ARRAY(_SET_COUNT + FT_EXTRA_SETS)
   LOCAL ii, aSetKeys := {}, aFunKeys := {}
   
   AEVAL(aOldSets, ;
         { | xElement, nElementNo | ;
           aOldSets[nElementNo] := SET(nElementNo) } )

   aOldSets[FT_SET_CENTURY] := FT_SETCENTURY()
   aOldSets[FT_SET_BLINK]   := SETBLINK()
   
#ifdef VFS_FS2TOOLS     
   aSetKeys := SaveSetKey()      // current SET KEY
   aFunKeys := FunKeyArr()       // current SET FUNCTION
   for ii := 1 to len(aSetKeys)
      aadd(aOldSets, {"SETKEY", aSetKeys[ii]})
   next 
   for ii := 1 to len(aFunKeys)
      aadd(aOldSets, {"FUNKEY", aFunKeys[ii]})
   next 
#endif
   
   RETURN (aOldSets)                    // FT_SaveSets
