/* This is a wrapper for FT_*() functions already available in FS2 Toolbox of FlagShip
 * Copyright 2012 by multisoft Datentechnik, Germany
 * Public domain for nanfor library used by FlagShip
 *
 * compile by supplied Makefile.*
 */
 
/* Note: the #define VFS_FS2TOOLS is automatically set if you own FS2 Toolbox.
 * If -DVFS_FS2TOOLS is not set (check by FlagShip -v ...) and you have 
 * FS2 with older FlagShip version, enable it here:
 */
// #define VFS_FS2TOOLS
#ifdef VFS_FS2TOOLS        
/*****************************************************************************
 * FS2 Tools available
 */
FUNCTION FT_DSKFREE(cDrive)                  // replaces prg/diskfunc.prg
   if len(cDrive) == 1 .and. IsAlpha(cDrive)
      cDrive += ":" + PATH_SLASH
   elseif empty(cDrive)
      cDrive := PATH_SLASH
   endif
   return DiskFree(cDrive) // FS2
             
FUNCTION FT_DSKSIZE(cDrive)                  // replaces prg/diskfunc.prg
   if len(cDrive) == 1 .and. IsAlpha(cDrive)
      cDrive += ":" + PATH_SLASH
   elseif empty(cDrive)
      cDrive := PATH_SLASH
   endif
   return DiskTotal(cDrive) // FS2

FUNCTION FT_MKDIR(cDir)                      // replaces asm/mkdir.asm and 
   local cFull, iRet := 99
   if empty(cDir)
      return 99
   endif
   cFull := truepath(cDir) 
   if empty(cFull)
      cFull := alltrim(cDir)
   endif
   if file(cFull)
      iRet := 5
   else
      iRet := DirMake(cFull) // FS2
   endif
   if iRet == -1
      return 99
   endif
   return abs(iRet)

FUNCTION FT_ONTICK([bVal], [iTicks])         // replaces c/ontick.c
   if pcount() < 1 .or. valtype(bVal) != "B" 
      return TriggerUdf(.F.)
   endif
   local iSec := 1 as intvar
   if valtype(iTicks) $ "IN"
      iSec := max(iTicks / 10, 1)            // assumes 10 Ticks/sec
   endif
   return TriggerUdf(bVal, iSec) // FS2

FUNCTION FT_RMDIR(cPath)                     // replaces asm/rmdir.asm
   local cFull, iRet := 99
   cFull := truepath(cPath)
   if empty(cFull)
      cFull := alltrim(cPath)
   endif
   if cFull == curdir()
      return 16
   endif
   if len(cFull) <= 3 .and. (empty(cFull) .or. ;
       left(cFull,1) $ "./\" .or. substr(cFull,2,1) == ":")
      return 99                              // just security, not for root
   endif   
   iRet := DirRemove(cFull)  // FS2
   if iRet == -1
      return 99
   endif
   return abs(iRet)

FUNCTION FT_SETDATE(dDate)                   // replaces prg/setdate.prg 
   return SetDate(dDate) // FS2

FUNCTION FT_SETKEYS()                        // replaces asm/setkeys.asm    
   return SetKeyArr()  // FS2        

FUNCTION FT_SETTIME(cTime)                   // replaces prg/settime.prg  
   if valtype(cTime) == "C" .and. len(cTime) >= 5
      return SetTime(cTime) // FS2
   endif
   return .F.

FUNCTION FT_TEMPFIL(cPath, lHide)            // replaces prg/tempfile.prg  
   if empty(cPath)
      cPath := PATH_SLASH
   endif
   return TempFile(cPath) // FS2

#else
/*****************************************************************************
 * FS2 Tools not available - retuns default value only
 */
#stdout **Info: some functions like FT_MKDIR, FT_DSK*, FT_ONTICK etc. requires FS2 Toolbox. 
#stdout ** Only dummy functions with default return value are generated.
FUNCTION FT_MKDIR(cDir)                      // replaces asm/mkdir.asm and 
   return 99
FUNCTION FT_DSKFREE(cDrive)                  // replaces prg/diskfunc.prg
   return 0
FUNCTION FT_DSKSIZE(cDrive)                  // replaces prg/diskfunc.prg
   return 0
FUNCTION FT_ONTICK([bVal], [iTicks])         // replaces c/ontick.c
   return .F.
FUNCTION FT_RMDIR(cPath)                     // replaces asm/rmdir.asm
   return 99
FUNCTION FT_SETDATE(dDate)                   // replaces prg/setdate.prg 
   return .F.
FUNCTION FT_SETKEYS()                        // replaces asm/setkeys.asm 
   return {}   
FUNCTION FT_SETTIME(cTime)                   // replaces prg/settime.prg  
   return .F.
FUNCTION FT_TEMPFIL(cPath, lHide)            // replaces prg/tempfile.prg  
   return ""            
#endif
* eof *
