/* This is a wrapper for FT_*() functions already available in FlagShip 7 and later
 * Functionality compatible to GUI and Terminal i/o mode
 * Copyright 2012 by multisoft Datentechnik, Germany
 * Public domain for nanfor library used by FlagShip
 *
 * compile by supplied Makefile.*
 */

#define CRLF chr(13) + chr(10)

FUNCTION FT_ADAPTER()                        // replaces asm/adapter.asm 
   return 3  // VGA
   
FUNCTION FT_ALT()                            // replaces c/alt.c
   return InkeyStatus(STATUS_ALT, .T.)

FUNCTION FT_CAPLOCK()                        // replaces c/caplock.c
   return InkeyStatus(STATUS_CAPSLOCK, .T.)

FUNCTION FT_CHDIR(cDir)                      // replaces asm/chdir.asm
   SET DIRECTORY TO (cDir)
   if upper(curdir()) == alltrim(upper(cDir))
      return 0
   endif
   return 3
      
FUNCTION FT_CTRL()                           // replaces c/ctrl.c
   return lastkey() == K_CTRL_C
   
FUNCTION FT_DEFAULT(cDrive)                  // replaces asm/default.asm
   local cRet
   if valtype(cDrive) == "C" .and. IsAlpha(cDrive)
      SET DIRECTORY TO (left(cDir,1) + ":")
   endif
   cRet := upper(left(curdir()),1)
   return if(IsAlpha(cRet), cRet, "")
      
FUNCTION FT_DESCEND(val)                     // replaces c/descend.c
   return Descend(val)
   
FUNCTION FT_DOSVER()                         // replaces prg/dosver.prg (not applicable)
   return ""
   
FUNCTION FT_FLOPTST(p1)                      // replaces prg/floptst.prg (not applicable)
   return 4 
      
FUNCTION FT_GETE(var)                        // replaces c/getenvrn.c
   local ii, aEnvir := GetEnvArr()
   if pcount() > 0
      if valtype(var) == "A"
         var := aclone(aEnvir)
      elseif valtype(var) == "C"
         var := ""
         for ii := 1 to len(aEnvir)
            var += aEnvir[ii,1] + "=" + aEnvir[ii,2] + CRLF
         next
      endif
   endif
   return len(aEnvir)

FUNCTION FT_GETVPG(p1)                       // replaces prg/page.prg (not applicable) 
   return NIL
     
FUNCTION FT_IAMIDLE()                        // replaces asm/iamidle.asm
   sleepms(100)      // avoid pooling
   return .F.
   
FUNCTION FT_IDLE()                           // replaces c/idle.c (not applicable)
   return NIL

FUNCTION FT_INP(p1)                          // replaces asm/inp.asm (not applicable)
   return 0

FUNCTION FT_INT86()                          // replaces c/int86.c (not applicable)
   return .F.

FUNCTION FT_ISPRINT(p1)                      // replaces asm/isprint.asm (not applicable)
   return .T.
   
FUNCTION FT_ISSHARE()                        // replaces prg/isshare.prg (not applicable) 
   return 0
     
FUNCTION FT_LASTKEY(val)                     // replaces asm/setlastk.asm
   Lastkey(0, , val)
   return
   
FUNCTION FT_NUMLOCK()                        // replaces c/numlock.c
   return InkeyStatus(STATUS_NUMLOCK, .T.)

FUNCTION FT_NWLSTAT()                        // replaces prg/nwlstat.prg  (dummy, not applicable) 
   return 0

FUNCTION FT_NWSEMCLOSE()                     // replaces prg/nwsem.prg  (dummy, not applicable)
   return 255
   
FUNCTION FT_NWSEMEX()                        // replaces prg/nwsem.prg  (dummy, not applicable)
   return 255
   
FUNCTION FT_NWSEMLOCK()                      // replaces prg/nwsem.prg  (dummy, not applicable)               
   return .F.
   
FUNCTION FT_NWSEMOPEN()                      // replaces prg/nwsem.prg  (dummy, not applicable)
   return 255
   
FUNCTION FT_NWSEMSIG()                       // replaces prg/nwsem.prg  (dummy, not applicable)               
   return 255
   
FUNCTION FT_NWSEMUNLOCK()                    // replaces prg/nwsem.prg  (dummy, not applicable)
   return .F.
   
FUNCTION FT_NWSEMWAIT()                      // replaces prg/nwsem.prg  (dummy, not applicable)              
   return 255
   
FUNCTION FT_NWUID()                          // replaces prg/nwuid.prg  (dummy, not applicable)             
   return
  
FUNCTION FT_ONIDLE(bVal)                     // replaces c/onidle.c
   if valtype(bVal) == "B"
      Eval(bVal)
   endif
   return 

FUNCTION FT_ORIGIN()                         // replaces c/origin.c
   return ExecName(.T., .T.)

FUNCTION FT_OUTP(p1,p2)                      // replaces asm/outp.asm (not applicable)
   return .F.
   
FUNCTION FT_PEEK(p1, p2)                     // replaces c/peek.c (not applicable)
   return -1

FUNCTION FT_POKE(p1, p2, p3)                 // replaces c/poke.c (not applicable)
   return .F.
   
FUNCTION FT_PRTSCR()                         // replaces c/prtscr.c (not applicable)
   return .F.

FUNCTION FT_PUTKEY(nKey)                     // replaces asm/putkey.asm
   KEYBOARD (nKey) ADDITIVE
   return .T.
   
FUNCTION FT_REBOOT()                         // replaces asm/reboot.asm  (not applicable) 
   return

FUNCTION FT_SCANCODE()                       // replaces prg/scancode.prg (not applicable) 
   return chr(Inkey(0))
     
FUNCTION FT_SETRATE(p1,p2)                   // replaces asm/kspeed.asm (not applicable)
   return NIL
   
FUNCTION FT_SHIFT()                          // replaces c/shift.c
   return InkeyStatus(STATUS_SHIFT, .T.)

FUNCTION FT_STOD(cDate)                      // replaces c/stod.c
   return Stod(cDate)
   
FUNCTION FT_SYSMEM()                         // replaces prg/sysmem.prg (dummy)
   return 512 * 1024 * 1024  // at least 512 Mbyte is installed
   
     
   